@@ -19,12 +19,10 @@
 # ============================================================================
 # Name        : FeedingIt.py
 # Author      : Yves Marcoz
-# Version     : 0.5.4
+# Version     : 0.6.0
 # Description : Simple RSS Reader
 # ============================================================================
 #import sys
-#sys.path.insert(0, '/opt/FeedingIt')
-#sys.path.insert(0, '/home/user/workspace/feedingit/src/')
 
 import gtk, pickle, gobject, dbus
 import hildondesktop, hildon
@@ -34,10 +32,18 @@ import hildondesktop, hildon
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
-bus = dbus.SessionBus()
+#bus = dbus.SessionBus()
+
+from os import environ
+bus = dbus.bus.BusConnection(environ["DBUS_SESSION_BUS_ADDRESS"])
 
 CONFIGDIR="/home/user/.feedingit/"
 
+#DBusConnection *hd_home_plugin_item_get_dbus_connection ( HDHomePluginItem *item, DBusBusType type, DBusError *error);
+#import ctypes
+#libc = ctypes.CDLL('libc.so.6')
+#libc.printf('Hello world!')
+
 class FeedingItHomePlugin(hildondesktop.HomePluginItem):
     def __init__(self):
       try:
@@ -48,10 +54,10 @@ class FeedingItHomePlugin(hildondesktop.HomePluginItem):
         
         vbox = gtk.VBox(False, 0)
         
-        button = gtk.Button("Update")
-        button.connect("clicked", self.update_list)
-        button.show_all()
-        vbox.pack_start(button)        
+        #button = gtk.Button("Update")
+        #button.connect("clicked", self.update_list)
+        #button.show_all()
+        #vbox.pack_start(button)        
         
         #for feed in ["Slashdot", "Engadget", "Cheez"]:
         #    self.treestore.append([feed, "0"])
@@ -67,12 +73,13 @@ class FeedingItHomePlugin(hildondesktop.HomePluginItem):
         self.add(vbox)
         self.treeview.connect("row-activated", self.row_activated)
         vbox.show_all()
-        #self.setupDbus()
-        gobject.timeout_add_seconds(30*60, self.update_list)
+        self.setupDbus()
+        #gobject.timeout_add_seconds(30*60, self.update_list)
       except:
           import traceback
           file = open("/home/user/.feedingit/feedingit_widget.log", "w")
           traceback.print_exc(file=file)
+          file.close()
 
     def row_activated(self, treeview, treepath, column):
         (model, iter) = self.treeview.get_selection().get_selected()
@@ -169,16 +176,14 @@ class FeedingItHomePlugin(hildondesktop.HomePluginItem):
         #bus = dbus.Bus.get_session(True)
         #bus.set_exit_on_disconnect(False)
         
-        remote_object = bus.get_object("org.maemo.feedingit", # Connection name
-                               "/org/maemo/feedingit" # Object's path
-                              )
-        iface = dbus.Interface(remote_object, 'org.maemo.feedingit')
-        iface.connect_to_signal("ArticleCountUpdated", self.update_list)
+        #remote_object = bus.get_object("org.maemo.feedingit", # Connection name
+        #                       "/org/maemo/feedingit" # Object's path
+        #                      )
+        #iface = dbus.Interface(remote_object, 'org.maemo.feedingit')
+        #iface.connect_to_signal("ArticleCountUpdated", self.update_list)
 
-        #bus.add_signal_receiver(self.update_list,
-        #                dbus_interface="org.maemo.feedingit",
-        #                signal_name="ArticleCountUpdated",
-        #                path="/org/maemo/feedingit")
+        bus.add_signal_receiver(self.update_list, dbus_interface="org.maemo.feedingit",
+                        signal_name="ArticleCountUpdated", path="/org/maemo/feedingit")
         
     def save_config(self):
             if not isdir(CONFIGDIR):
